pub struct HeightField { /* private fields */ }Expand description
A 2D heightfield with a generic storage buffer for its heights.
Implementations
Sourceimpl HeightField
impl HeightField
Sourceimpl HeightField
impl HeightField
Sourcepub fn bounding_sphere(&self, pos: &Pose) -> BoundingSphere
pub fn bounding_sphere(&self, pos: &Pose) -> BoundingSphere
Computes the world-space bounding sphere of this height-field, transformed by pos.
Sourcepub fn local_bounding_sphere(&self) -> BoundingSphere
pub fn local_bounding_sphere(&self) -> BoundingSphere
Computes the local-space bounding sphere of this height-field.
Sourceimpl HeightField
impl HeightField
Sourceimpl HeightField
impl HeightField
Sourcepub fn set_scale(&mut self, new_scale: Vector)
pub fn set_scale(&mut self, new_scale: Vector)
Sets the scale factor applied to this heightfield.
Sourcepub fn cell_width(&self) -> f32
pub fn cell_width(&self) -> f32
The width of a single cell of this heightfield.
Sourcepub fn unit_cell_width(&self) -> f32
pub fn unit_cell_width(&self) -> f32
The width of a single cell of this heightfield, without taking the scale factor into account.
Sourcepub fn cell_at_point(&self, pt: Vector2) -> Option<usize>
pub fn cell_at_point(&self, pt: Vector2) -> Option<usize>
Index of the cell a point is on after vertical projection.
Sourcepub fn height_at_point(&self, pt: Vector2) -> Option<f32>
pub fn height_at_point(&self, pt: Vector2) -> Option<f32>
Height of the heightfield at the given point after vertical projection on the heightfield surface.
Sourcepub fn segments(&self) -> impl Iterator<Item = Segment> + '_
pub fn segments(&self) -> impl Iterator<Item = Segment> + '_
Iterator through all the segments of this heightfield.
Sourcepub fn segment_at(&self, i: usize) -> Option<Segment>
pub fn segment_at(&self, i: usize) -> Option<Segment>
The i-th segment of the heightfield if it has not been removed.
Sourcepub fn set_segment_removed(&mut self, i: usize, removed: bool)
pub fn set_segment_removed(&mut self, i: usize, removed: bool)
Mark the i-th segment of this heightfield as removed or not.
Sourcepub fn is_segment_removed(&self, i: usize) -> bool
pub fn is_segment_removed(&self, i: usize) -> bool
Checks if the i-th segment has been removed.
Sourcepub fn unclamped_elements_range_in_local_aabb(
&self,
aabb: &Aabb,
) -> Range<isize>
pub fn unclamped_elements_range_in_local_aabb( &self, aabb: &Aabb, ) -> Range<isize>
The range of segment ids that may intersect the given local Aabb.
Sourceimpl HeightField
impl HeightField