pub trait PolygonalFeatureMap: SupportMap {
// Required method
fn local_support_feature(
&self,
dir: Vector,
out_feature: &mut PolygonalFeature,
);
// Provided method
fn is_convex_polyhedron(&self) -> bool { ... }
}Expand description
Trait implemented by convex shapes with features with polyhedral approximations.
Required Methods
Sourcefn local_support_feature(&self, dir: Vector, out_feature: &mut PolygonalFeature)
fn local_support_feature(&self, dir: Vector, out_feature: &mut PolygonalFeature)
Compute the support polygonal face of self towards the dir.
Provided Methods
Sourcefn is_convex_polyhedron(&self) -> bool
fn is_convex_polyhedron(&self) -> bool
Is this shape a ConvexPolyhedron?